##  Define Organizations
**Tip**
For your initial assessment, focus on the most important organizations and expand the scope later.
To define organizations, involve your business stakeholders. Collaborate with business, HR, and regional managers to ensure accuracy.
You can use the following fact sheet subtypes for the five major dimensions that SAP LeanIX customers typically capture:
  * Business Unit: Business units are distinct divisions within a larger organization.
Example: Retail
  * Customer: Customers represent customer groups/segments with similar needs.
Example: Buyer Persona
  * Region: Regions represent geographical divisions within a larger organization and/or business unit.
Example: Europe, Europe / France
  * Legal Entity: Legal entities are organizations recognized by law as distinct entities.
Example: SAP LeanIX SARL
  * Team: Teams are groups of users or owners that are typically part of specific business units or countries.
Example: Team Igniteus
